@@ -371,7 +371,11 @@ timeout (GtkWidget *widget)
   getvelocity ();
   getposition ();
 
-  gtk_widget_queue_draw (widget);
+  /* Invalidate the whole window. */
+  gdk_window_invalidate_rect (widget->window, &widget->allocation, FALSE);
+
+  /* Update synchronously (fast). */
+  gdk_window_process_updates (widget->window, FALSE);
 
   return TRUE;
 }
@@ -406,7 +410,7 @@ motion_notify_event (GtkWidget      *widget,
   beginY = event->y;
 
   if (redraw && !animate)
-    gtk_widget_queue_draw (widget);
+    gdk_window_invalidate_rect (widget->window, &widget->allocation, FALSE);
 
   return TRUE;
 }
@@ -497,7 +501,7 @@ key_press_event (GtkWidget   *widget,
     }
 
   if (!animate)
-    gtk_widget_queue_draw (widget);
+    gdk_window_invalidate_rect (widget->window, &widget->allocation, FALSE);
 
   return TRUE;
 }
@@ -616,7 +620,7 @@ toggle_animation (GtkWidget *widget)
   else
     {
       timeout_remove (widget);
-      gtk_widget_queue_draw (widget);
+      gdk_window_invalidate_rect (widget->window, &widget->allocation, FALSE);
     }
 }
 
@@ -627,7 +631,7 @@ static void
 init_wireframe (GtkWidget *widget)
 {
   resetWireframe ();
-  gtk_widget_queue_draw (widget);
+  gdk_window_invalidate_rect (widget->window, &widget->allocation, FALSE);
 }
 
 
@@ -738,10 +742,6 @@ create_window (GdkGLConfig *glconfig)
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), DEFAULT_TITLE);
 
-#ifndef G_OS_WIN32
-  /* Perform the resizes immediately */
-  gtk_container_set_resize_mode (GTK_CONTAINER (window), GTK_RESIZE_IMMEDIATE);
-#endif
   /* Get automatically redrawn if any of their children changed allocation. */
   gtk_container_set_reallocate_redraws (GTK_CONTAINER (window), TRUE);
 
