@@ -406,7 +406,7 @@ motion_notify_event (GtkWidget      *widget,
   begin_y = y;
 
   if (redraw && !animate)
-    gtk_widget_queue_draw (widget);
+    gdk_window_invalidate_rect (widget->window, &widget->allocation, FALSE);
 
   return TRUE;
 }
@@ -437,7 +437,11 @@ key_press_event (GtkWidget   *widget,
 static gboolean
 timeout (GtkWidget *widget)
 {
-  gtk_widget_queue_draw (widget);
+  /* Invalidate the whole window. */
+  gdk_window_invalidate_rect (widget->window, &widget->allocation, FALSE);
+
+  /* Update synchronously. */
+  gdk_window_process_updates (widget->window, FALSE);
 
   return TRUE;
 }
@@ -514,7 +518,7 @@ toggle_animation (GtkWidget *widget)
   else
     {
       timeout_remove (widget);
-      gtk_widget_queue_draw (widget);
+      gdk_window_invalidate_rect (widget->window, &widget->allocation, FALSE);
     }
 }
 
@@ -527,7 +531,7 @@ init_logo_view (GtkWidget *widget)
   counter = 0;
 
   if (!animate)
-    gtk_widget_queue_draw (widget);
+    gdk_window_invalidate_rect (widget->window, &widget->allocation, FALSE);
 }
 
 /* For popup menu. */
@@ -734,10 +738,6 @@ main(int   argc,
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), "logo");
 
-#ifndef G_OS_WIN32
-  /* Perform the resizes immediately */
-  gtk_container_set_resize_mode (GTK_CONTAINER (window), GTK_RESIZE_IMMEDIATE);
-#endif
   /* Get automatically redrawn if any of their children changed allocation. */
   gtk_container_set_reallocate_redraws (GTK_CONTAINER (window), TRUE);
 
