@@ -47,6 +47,9 @@ static void     gtk_gl_widget_realize            (GtkWidget         *widget,
 static gboolean gtk_gl_widget_configure_event    (GtkWidget         *widget,
                                                   GdkEventConfigure *event,
                                                   GLWidgetPrivate   *private);
+static void     gtk_gl_widget_size_allocate      (GtkWidget         *widget,
+                                                  GtkAllocation     *allocation,
+                                                  GLWidgetPrivate   *private);
 static void     gtk_gl_widget_unrealize          (GtkWidget         *widget,
                                                   GLWidgetPrivate   *private);
 static void     gtk_gl_widget_parent_set         (GtkWidget         *widget,
@@ -70,14 +73,15 @@ gtk_gl_widget_realize (GtkWidget       *widget,
 {
   GdkGLWindow *glwindow;
 
-  GTK_GL_NOTE (FUNC, g_message (" - gtk_gl_widget_realize ()"));
+  GTK_GL_NOTE_FUNC_PRIVATE ();
+
+  /*
+   * Set OpenGL-capability to widget->window, then connect some signal
+   * handlers.
+   */
 
   if (!gdk_window_is_gl_capable (widget->window))
     {
-      /*
-       * Set OpenGL-capability to widget->window.
-       */
-
       glwindow = gdk_window_set_gl_capability (widget->window,
                                                private->glconfig,
                                                NULL);
@@ -87,10 +91,7 @@ gtk_gl_widget_realize (GtkWidget       *widget,
           return;
         }
 
-      /*
-       * Connect "unrealize" signal handler.
-       */
-
+      /* Connect "unrealize" signal handler. */
       if (private->unrealize_handler == 0)
         private->unrealize_handler = g_signal_connect (G_OBJECT (widget), "unrealize",
                                                        G_CALLBACK (gtk_gl_widget_unrealize),
@@ -105,31 +106,49 @@ gtk_gl_widget_configure_event (GtkWidget         *widget,
                                GdkEventConfigure *event,
                                GLWidgetPrivate   *private)
 {
+  GTK_GL_NOTE_FUNC_PRIVATE ();
+
   if (!private->is_realized)
     {
-      GTK_GL_NOTE (FUNC, g_message (" - gtk_gl_widget_configure_event ()"));
-
-      /* Realize. */
+      /* Realize if OpenGL-capable window is not realized yet. */
       gtk_gl_widget_realize (widget, private);
     }
 
   return FALSE;
 }
 
+static void
+gtk_gl_widget_size_allocate (GtkWidget       *widget,
+                             GtkAllocation   *allocation,
+                             GLWidgetPrivate *private)
+{
+  GdkGLDrawable *gldrawable;
+
+  GTK_GL_NOTE_FUNC_PRIVATE ();
+
+  /*
+   * Synchronize OpenGL and window resizing request streams.
+   */
+
+  if (GTK_WIDGET_REALIZED (widget) && private->is_realized)
+    {
+      gldrawable = gdk_window_get_gl_drawable (widget->window);
+      gdk_gl_drawable_wait_gdk (gldrawable);
+    }
+}
+
 static void
 gtk_gl_widget_unrealize (GtkWidget       *widget,
                          GLWidgetPrivate *private)
 {
-  GTK_GL_NOTE (FUNC, g_message (" - gtk_gl_widget_unrealize ()"));
+  GTK_GL_NOTE_FUNC_PRIVATE ();
 
-  if (widget->window != NULL)
-    {
-      /*
-       * Remove OpenGL-capability from widget->window.
-       */
+  /*
+   * Remove OpenGL-capability from widget->window.
+   */
 
-      gdk_window_unset_gl_capability (widget->window);
-    }
+  if (GTK_WIDGET_REALIZED (widget))
+    gdk_window_unset_gl_capability (widget->window);
 
   private->is_realized = FALSE;
 }
@@ -141,7 +160,11 @@ gtk_gl_widget_parent_set (GtkWidget   *widget,
 {
   GtkWidget *toplevel;
 
-  GTK_GL_NOTE (FUNC, g_message (" - gtk_gl_widget_parent_set ()"));
+  GTK_GL_NOTE_FUNC_PRIVATE ();
+
+  /*
+   * Try to install colormap to the top-level window.
+   */
 
   toplevel = gtk_widget_get_toplevel (widget);
   if (GTK_WIDGET_TOPLEVEL (toplevel) && !GTK_WIDGET_REALIZED (toplevel))
@@ -158,7 +181,7 @@ gtk_gl_widget_style_set (GtkWidget *widget,
                          GtkStyle  *previous_style,
                          gpointer   user_data)
 {
-  GTK_GL_NOTE (FUNC, g_message (" - gtk_gl_widget_style_set ()"));
+  GTK_GL_NOTE_FUNC_PRIVATE ();
 
   /* 
    * Set a background of "None" on window to avoid AIX X server crash.
@@ -181,13 +204,12 @@ gtk_gl_widget_style_set (GtkWidget *widget,
 static void
 gl_widget_private_destroy (GLWidgetPrivate *private)
 {
-  GTK_GL_NOTE (FUNC, g_message (" - gl_widget_private_destroy ()"));
+  GTK_GL_NOTE_FUNC_PRIVATE ();
 
   g_object_unref (G_OBJECT (private->glconfig));
 
   if (private->share_list != NULL)
-    g_object_remove_weak_pointer (G_OBJECT (private->share_list),
-                                  (gpointer *) &(private->share_list));
+    g_object_unref (G_OBJECT (private->share_list));
 
   g_free (private);
 }
@@ -218,9 +240,10 @@ gtk_widget_set_gl_capability (GtkWidget    *widget,
   GdkColormap *colormap;
   GLWidgetPrivate *private;
 
-  GTK_GL_NOTE (FUNC, g_message (" - gtk_widget_set_gl_capability ()"));
+  GTK_GL_NOTE_FUNC ();
 
   g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
+  g_return_val_if_fail (!GTK_WIDGET_NO_WINDOW (widget), FALSE);
   g_return_val_if_fail (!GTK_WIDGET_REALIZED (widget), FALSE);
   g_return_val_if_fail (GDK_IS_GL_CONFIG (glconfig), FALSE);
 
@@ -292,8 +315,7 @@ gtk_widget_set_gl_capability (GtkWidget    *widget,
   if (share_list != NULL && GDK_IS_GL_CONTEXT (share_list))
     {
       private->share_list = share_list;
-      g_object_add_weak_pointer (G_OBJECT (private->share_list),
-                                 (gpointer *) &(private->share_list));
+      g_object_ref (G_OBJECT (private->share_list));
     }
   else
     {
@@ -317,15 +339,24 @@ gtk_widget_set_gl_capability (GtkWidget    *widget,
    * Connect signal handlers to realize OpenGL-capable widget.
    */
 
-  g_signal_connect_after (G_OBJECT (widget), "realize",
-                          G_CALLBACK (gtk_gl_widget_realize),
-                          private);
+  g_signal_connect (G_OBJECT (widget), "realize",
+                    G_CALLBACK (gtk_gl_widget_realize),
+                    private);
 
   /* gtk_drawing_area sends configure_event when it is realized. */
   g_signal_connect (G_OBJECT (widget), "configure_event",
                     G_CALLBACK (gtk_gl_widget_configure_event),
                     private);
 
+  /*
+   * Connect "size_allocate" signal handler to synchronize OpenGL and
+   * window resizing request streams.
+   */
+
+  g_signal_connect (G_OBJECT (widget), "size_allocate",
+                    G_CALLBACK (gtk_gl_widget_size_allocate),
+                    private);
+
   return TRUE;
 }
 
@@ -392,6 +423,8 @@ gtk_widget_create_gl_context (GtkWidget    *widget,
   GdkGLDrawable *gldrawable;
   GdkGLContext *glcontext;
 
+  GTK_GL_NOTE_FUNC ();
+
   g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
   g_return_val_if_fail (GTK_WIDGET_REALIZED (widget), NULL);
 
@@ -420,7 +453,7 @@ static void
 gtk_gl_widget_destroy_gl_context (GtkWidget       *widget,
                                   GLWidgetPrivate *private)
 {
-  GTK_GL_NOTE (FUNC, g_message (" - gtk_gl_widget_destroy_gl_context ()"));
+  GTK_GL_NOTE_FUNC_PRIVATE ();
 
   /*
    * Destroy OpenGL rendering context.
